chaincode

package module
v0.0.0-...-5c1c42f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 22, 2023 License: MIT Imports: 7 Imported by: 0

Documentation

Overview

Package chaincode contains the code necessary for chaincode to interact with a Hyperledger Fabric peer.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Property

type Property struct {
	// contains filtered or unexported fields
}

type REState

type REState struct {
	contractapi.Contract
	Name               string
	Info               metadata.InfoMetadata
	UnknownTransaction interface{}
	BeforeTransaction  interface{}
	AfterTransaction   interface{}
}

Fabric enforces that every chaincode must implement Chaincode interface.

func (*REState) CreateProperty

func (c *REState) CreateProperty(
	ctx contractapi.TransactionContextInterface,
	propId string,
	propLocation string,
	propPrice int,
	sellerAddr string,
	buyerAddr string,
	soldStatus bool,
	isForSaleStatus bool) error

func (*REState) Init

Init: called when the chaincode is instantiated by the blockchain network

func (*REState) InitLedger

To create the transaction context for the function defined within the smart contract that read and write data to the blockchain ledger.

func (*REState) Invoke

func (c *REState) Invoke(stub shim.ChaincodeStubInterface) pb.Response

Invoke: called when the client invokes a specific function to process the transaction proposal

Directories

Path Synopsis

Jump to