Documentation
¶
Overview ¶
Package chaincode contains the code necessary for chaincode to interact with a Hyperledger Fabric peer.
Index ¶
- type Property
- type REState
- func (c *REState) CreateProperty(ctx contractapi.TransactionContextInterface, propId string, ...) error
- func (c *REState) Init(stub shim.ChaincodeStubInterface) pb.Response
- func (c *REState) InitLedger(ctx contractapi.TransactionContextInterface) error
- func (c *REState) Invoke(stub shim.ChaincodeStubInterface) pb.Response
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type REState ¶
type REState struct {
contractapi.Contract
Name string
Info metadata.InfoMetadata
UnknownTransaction interface{}
BeforeTransaction interface{}
AfterTransaction interface{}
}
Fabric enforces that every chaincode must implement Chaincode interface.
func (*REState) CreateProperty ¶
func (*REState) Init ¶
func (c *REState) Init(stub shim.ChaincodeStubInterface) pb.Response
Init: called when the chaincode is instantiated by the blockchain network
func (*REState) InitLedger ¶
func (c *REState) InitLedger(ctx contractapi.TransactionContextInterface) error
To create the transaction context for the function defined within the smart contract that read and write data to the blockchain ledger.
Click to show internal directories.
Click to hide internal directories.